@@ -8,13 +8,16 @@ from pre_commit import five
 
 
 # TODO: smell: import side-effects
-COLS = int(
-    subprocess.Popen(
-        ['tput', 'cols'], stdout=subprocess.PIPE,
-    ).communicate()[0] or
-    # Default in the case of no terminal
-    80
-)
+try:
+    COLS = int(
+        subprocess.Popen(
+            ['tput', 'cols'], stdout=subprocess.PIPE,
+        ).communicate()[0] or
+        # Default in the case of no terminal
+        80
+    )
+except OSError:  # pragma: no cover (windows)
+    COLS = 80
 
 
 def get_hook_message(
