@@ -1,5 +1,8 @@
 from __future__ import unicode_literals
 
+import logging
+import shutil
+
 from cached_property import cached_property
 
 from pre_commit.languages.all import languages
@@ -7,6 +10,9 @@ from pre_commit.manifest import Manifest
 from pre_commit.prefixed_command_runner import PrefixedCommandRunner
 
 
+logger = logging.getLogger('pre_commit')
+
+
 class Repository(object):
     def __init__(self, repo_config, repo_path_getter):
         self.repo_config = repo_config
@@ -60,15 +66,39 @@ class Repository(object):
 
     def install(self):
         """Install the hook repository."""
+        def language_is_installed(language_name):
+            language = languages[language_name]
+            return (
+                language.ENVIRONMENT_DIR is None or
+                self.cmd_runner.exists(language.ENVIRONMENT_DIR, '.installed')
+            )
+
+        if not all(
+            language_is_installed(language_name)
+            for language_name, _ in self.languages
+        ):
+            logger.info(
+                'Installing environment for {0}.'.format(self.repo_url)
+            )
+            logger.info('Once installed this environment will be reused.')
+            logger.info('This may take a few minutes...')
+
         for language_name, language_version in self.languages:
             language = languages[language_name]
-            if (
-                language.ENVIRONMENT_DIR is None or
-                self.cmd_runner.exists(language.ENVIRONMENT_DIR)
-            ):
-                # The language is already installed
+            if language_is_installed(language_name):
                 continue
+
+            # There's potentially incomplete cleanup from previous runs
+            # Clean it up!
+            if self.cmd_runner.exists(language.ENVIRONMENT_DIR):
+                shutil.rmtree(self.cmd_runner.path(language.ENVIRONMENT_DIR))
+
             language.install_environment(self.cmd_runner, language_version)
+            # Touch the .installed file (atomic) to indicate we've installed
+            open(
+                self.cmd_runner.path(language.ENVIRONMENT_DIR, '.installed'),
+                'w',
+            ).close()
 
     def run_hook(self, hook, file_args):
         """Run a hook.
