@@ -2,6 +2,7 @@ from __future__ import unicode_literals
 
 import os
 import os.path
+
 from cached_property import cached_property
 
 import pre_commit.constants as C
@@ -42,16 +43,16 @@ class Runner(object):
             repository.require_installed()
         return repositories
 
-    @cached_property
-    def pre_commit_path(self):
-        return os.path.join(self.git_root, '.git', 'hooks', 'pre-commit')
+    def get_hook_path(self, hook_type):
+        return os.path.join(self.git_root, '.git', 'hooks', hook_type)
 
     @cached_property
-    def pre_commit_legacy_path(self):
-        """The path in the 'hooks' directory representing the temporary
-        storage for existing pre-commit hooks.
-        """
-        return self.pre_commit_path + '.legacy'
+    def pre_commit_path(self):
+        return self.get_hook_path('pre-commit')
+
+    @cached_property
+    def pre_push_path(self):
+        return self.get_hook_path('pre-push')
 
     @cached_property
     def cmd_runner(self):
